print.summary.BANOVA.Normal <-
function(x, ...){
  cat('Call:\n')
  print(x$call)
  
  cat('\nConvergence diagnostics:\n')
  print(x$conv)
  
  cat('\nTable of sum of squares and effect sizes (Bayesian ANOVA/ANCOVA):\n')
  print(x$anova.table)
  
  cat('\nTable of p-values (Multidimensional): \n')
  print(x$pvalue.table)
  
  cat('\nTable of coefficients: \n')
  printCoefmat(x$coef.table)
  
  cat('\nTable of means: \n')
  table.means(x$full_object)
  
}
